/*
 * PropertiesParser.java
 *
 * Created on 18 May 2009
 *
 * Version 1.1
 *
 * Copyright (c) Kieran Greer
 */

package org.jlog2.util;


import org.jlog2.channel.*;

import java.io.FileInputStream;
import java.util.*;


/**
 * This class acts as a parser of a properties file to configure the logger
 * @author Kieran Greer
 */
public class PropertiesParser
{
    /** The properties object */
    private Properties props;

    
    /**
     * Create a new instance of PropertiesParser.
     * @throws java.lang.Exception any error.
     */
    public PropertiesParser() throws Exception
    {
        loadProperties();
    }
    
    /**
     * Load in the properties file values.
     * @throws java.lang.Exception any error.
     */
    private void loadProperties() throws Exception
    {
        props = new Properties();

        try
        {
            props.load(new FileInputStream(ConfigHandler.getConfigFile()));
        }
        catch (Exception ex)
        {
            props = new Properties();
        }
    }

    /**
     * Get the properties that configure the loggers.
     * @return the properties read from a file.
     */
    public Properties getProperties()
    {
        return props;
    }

    /**
     * Initialise some values.
     * @param logChannels the log channels object to initialise. Keys are the
     * logger keys while values are the default channels.
     * @param debugChannels the debug channels object to initialise. Keys are the
     * logger keys while values are the default channels.
     * @throws java.lang.Exception any error.
     */
    public void initialiseChannels(Hashtable logChannels, Hashtable debugChannels) throws Exception
    {
        int fileSize;                           //file size
        int backupNumber;                       //number of backup files
        String filePath;                        //file path
        String defaultChannels;                 //default log channels
        String nextProperty;                    //next property
        LogChannel nextChannel;                 //next log channel

        //parse the default channels
        if (props.containsKey(LogConst.LOGCHANNELS))
        {
            defaultChannels = props.getProperty(LogConst.LOGCHANNELS).toLowerCase();

            if (defaultChannels.indexOf(LogConst.STDOUTKEY) >= 0)
            {
                nextChannel = new StdOutChannel();
                logChannels.put(LogConst.STDOUTID, nextChannel);
            }

            if (defaultChannels.indexOf(LogConst.STDERRKEY) >= 0)
            {
                nextChannel = new StdErrChannel();
                logChannels.put(LogConst.STDERRID, nextChannel);
            }

            if (defaultChannels.indexOf(LogConst.FILEKEY) >= 0)
            {
                if (props.containsKey(LogConst.LOGFILEPATH))
                {
                    filePath = (ConfigHandler.getLogFolder() + "/" + 
                            props.getProperty(LogConst.LOGFILEPATH));

                    if (props.containsKey(LogConst.LOGFILESIZE))
                    {
                        nextProperty = props.getProperty(LogConst.LOGFILESIZE);
                        fileSize = Integer.parseInt(nextProperty);
                    }
                    else
                    {
                        fileSize = ConfigHandler.getDefaultFileSize();
                    }

                    if (props.containsKey(LogConst.LOGFILEBACKUP))
                    {
                        nextProperty = props.getProperty(LogConst.LOGFILEBACKUP);
                        backupNumber = Integer.parseInt(nextProperty);
                    }
                    else
                    {
                        backupNumber = 0;
                    }

                    nextChannel = new FileChannel(filePath, fileSize, backupNumber);
                    logChannels.put(LogConst.STDFILEID, nextChannel);
                }
            }
        }

        if (props.containsKey(LogConst.DEBUGCHANNELS))
        {
            defaultChannels = props.getProperty(LogConst.DEBUGCHANNELS).toLowerCase();

            if (defaultChannels.indexOf(LogConst.STDOUTKEY) >= 0)
            {
                nextChannel = new StdOutChannel();
                debugChannels.put(LogConst.STDOUTID, nextChannel);
            }

            if (defaultChannels.indexOf(LogConst.STDERRKEY) >= 0)
            {
                nextChannel = new StdErrChannel();
                debugChannels.put(LogConst.STDERRID, nextChannel);
            }

            if (defaultChannels.indexOf(LogConst.FILEKEY) >= 0)
            {
                if (props.containsKey(LogConst.DEBUGFILEPATH))
                {
                    filePath = (ConfigHandler.getLogFolder() + "/" + 
                            props.getProperty(LogConst.DEBUGFILEPATH));

                    if (props.containsKey(LogConst.DEBUGFILESIZE))
                    {
                        nextProperty = props.getProperty(LogConst.DEBUGFILESIZE);
                        fileSize = Integer.parseInt(nextProperty);
                    }
                    else
                    {
                        fileSize = ConfigHandler.getDefaultFileSize();
                    }

                    if (props.containsKey(LogConst.DEBUGFILEBACKUP))
                    {
                        nextProperty = props.getProperty(LogConst.DEBUGFILEBACKUP);
                        backupNumber = Integer.parseInt(nextProperty);
                    }
                    else
                    {
                        backupNumber = 0;
                    }

                    nextChannel = new FileChannel(filePath, fileSize, backupNumber);
                    debugChannels.put(LogConst.STDFILEID, nextChannel);
                }
            }
        }
    }
}
